package com.ruoyi.web.modules.industrypolicy.service;

import java.util.List;
import com.ruoyi.web.modules.industrypolicy.domain.BizSubsidyProject;

/**
 * 项目与补贴-项目服务
 */
public interface IBizSubsidyProjectService
{
    BizSubsidyProject selectBizSubsidyProjectById(Long id);

    List<BizSubsidyProject> selectBizSubsidyProjectList(BizSubsidyProject query);

    int insertBizSubsidyProject(BizSubsidyProject row);

    int updateBizSubsidyProject(BizSubsidyProject row);

    int deleteBizSubsidyProjectByIds(Long[] ids);

    int publish(Long id);

    int offline(Long id);
}
